<a id="mypy-boto3-quicksight"></a>

# mypy-boto3-quicksight

[![PyPI - mypy-boto3-quicksight](https://img.shields.io/pypi/v/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-quicksight?color=blue)](https://pypistats.org/packages/mypy-boto3-quicksight)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.QuickSight 1.19.9](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/quicksight.html#QuickSight)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-quicksight docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-quicksight](#mypy-boto3-quicksight)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `QuickSight` service.

```bash
python -m pip install boto3-stubs[quicksight]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`

Both type checking and auto-complete should work for `QuickSight` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`

Both type checking and auto-complete should work for `QuickSight` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`
- Run `mypy` as usual

Type checking should work for `QuickSight` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `QuickSight` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`QuickSightClient` provides annotations for `boto3.client("quicksight")`.

```python
import boto3

from mypy_boto3_quicksight import QuickSightClient

client: QuickSightClient = boto3.client("quicksight")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: QuickSightClient = session.client("quicksight")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_quicksight.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_quicksight import QuickSightClient
from mypy_boto3_quicksight.paginator import (
    ListAnalysesPaginator,
    ListDashboardVersionsPaginator,
    ListDashboardsPaginator,
    ListDataSetsPaginator,
    ListDataSourcesPaginator,
    ListIngestionsPaginator,
    ListNamespacesPaginator,
    ListTemplateAliasesPaginator,
    ListTemplateVersionsPaginator,
    ListTemplatesPaginator,
    ListThemeVersionsPaginator,
    ListThemesPaginator,
    SearchAnalysesPaginator,
    SearchDashboardsPaginator,
)

client: QuickSightClient = boto3.client("quicksight")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_analyses_paginator: ListAnalysesPaginator = client.get_paginator("list_analyses")
list_dashboard_versions_paginator: ListDashboardVersionsPaginator = client.get_paginator("list_dashboard_versions")
list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
list_data_sources_paginator: ListDataSourcesPaginator = client.get_paginator("list_data_sources")
list_ingestions_paginator: ListIngestionsPaginator = client.get_paginator("list_ingestions")
list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
list_template_aliases_paginator: ListTemplateAliasesPaginator = client.get_paginator("list_template_aliases")
list_template_versions_paginator: ListTemplateVersionsPaginator = client.get_paginator("list_template_versions")
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
list_theme_versions_paginator: ListThemeVersionsPaginator = client.get_paginator("list_theme_versions")
list_themes_paginator: ListThemesPaginator = client.get_paginator("list_themes")
search_analyses_paginator: SearchAnalysesPaginator = client.get_paginator("search_analyses")
search_dashboards_paginator: SearchDashboardsPaginator = client.get_paginator("search_dashboards")
```

<a id="literals"></a>

### Literals

`mypy_boto3_quicksight.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_quicksight.literals import (
    AnalysisErrorTypeType,
    AnalysisFilterAttributeType,
    AssignmentStatusType,
    ColumnDataTypeType,
    ColumnTagNameType,
    DashboardBehaviorType,
    DashboardErrorTypeType,
    DashboardFilterAttributeType,
    DashboardUIStateType,
    DataSetImportModeType,
    DataSourceErrorInfoTypeType,
    DataSourceTypeType,
    EditionType,
    EmbeddingIdentityTypeType,
    FileFormatType,
    FilterOperatorType,
    FolderFilterAttributeType,
    FolderTypeType,
    GeoSpatialCountryCodeType,
    GeoSpatialDataRoleType,
    IdentityStoreType,
    IdentityTypeType,
    IngestionErrorTypeType,
    IngestionRequestSourceType,
    IngestionRequestTypeType,
    IngestionStatusType,
    IngestionTypeType,
    InputColumnDataTypeType,
    JoinTypeType,
    ListAnalysesPaginatorName,
    ListDashboardVersionsPaginatorName,
    ListDashboardsPaginatorName,
    ListDataSetsPaginatorName,
    ListDataSourcesPaginatorName,
    ListIngestionsPaginatorName,
    ListNamespacesPaginatorName,
    ListTemplateAliasesPaginatorName,
    ListTemplateVersionsPaginatorName,
    ListTemplatesPaginatorName,
    ListThemeVersionsPaginatorName,
    ListThemesPaginatorName,
    MemberTypeType,
    NamespaceErrorTypeType,
    NamespaceStatusType,
    ResourceStatusType,
    RowLevelPermissionFormatVersionType,
    RowLevelPermissionPolicyType,
    SearchAnalysesPaginatorName,
    SearchDashboardsPaginatorName,
    StatusType,
    TemplateErrorTypeType,
    TextQualifierType,
    ThemeErrorTypeType,
    ThemeTypeType,
    UserRoleType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AnalysisErrorTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_quicksight.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_quicksight.type_defs import (
    AccountCustomizationTypeDef,
    AccountSettingsTypeDef,
    ActiveIAMPolicyAssignmentTypeDef,
    AdHocFilteringOptionTypeDef,
    AmazonElasticsearchParametersTypeDef,
    AmazonOpenSearchParametersTypeDef,
    AnalysisErrorTypeDef,
    AnalysisSearchFilterTypeDef,
    AnalysisSourceEntityTypeDef,
    AnalysisSourceTemplateTypeDef,
    AnalysisSummaryTypeDef,
    AnalysisTypeDef,
    AnonymousUserDashboardEmbeddingConfigurationTypeDef,
    AnonymousUserEmbeddingExperienceConfigurationTypeDef,
    AthenaParametersTypeDef,
    AuroraParametersTypeDef,
    AuroraPostgreSqlParametersTypeDef,
    AwsIotAnalyticsParametersTypeDef,
    BorderStyleTypeDef,
    CalculatedColumnTypeDef,
    CancelIngestionRequestRequestTypeDef,
    CancelIngestionResponseTypeDef,
    CastColumnTypeOperationTypeDef,
    ColumnDescriptionTypeDef,
    ColumnGroupColumnSchemaTypeDef,
    ColumnGroupSchemaTypeDef,
    ColumnGroupTypeDef,
    ColumnLevelPermissionRuleTypeDef,
    ColumnSchemaTypeDef,
    ColumnTagTypeDef,
    CreateAccountCustomizationRequestRequestTypeDef,
    CreateAccountCustomizationResponseTypeDef,
    CreateAnalysisRequestRequestTypeDef,
    CreateAnalysisResponseTypeDef,
    CreateColumnsOperationTypeDef,
    CreateDashboardRequestRequestTypeDef,
    CreateDashboardResponseTypeDef,
    CreateDataSetRequestRequestTypeDef,
    CreateDataSetResponseTypeDef,
    CreateDataSourceRequestRequestTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateFolderMembershipRequestRequestTypeDef,
    CreateFolderMembershipResponseTypeDef,
    CreateFolderRequestRequestTypeDef,
    CreateFolderResponseTypeDef,
    CreateGroupMembershipRequestRequestTypeDef,
    CreateGroupMembershipResponseTypeDef,
    CreateGroupRequestRequestTypeDef,
    CreateGroupResponseTypeDef,
    CreateIAMPolicyAssignmentRequestRequestTypeDef,
    CreateIAMPolicyAssignmentResponseTypeDef,
    CreateIngestionRequestRequestTypeDef,
    CreateIngestionResponseTypeDef,
    CreateNamespaceRequestRequestTypeDef,
    CreateNamespaceResponseTypeDef,
    CreateTemplateAliasRequestRequestTypeDef,
    CreateTemplateAliasResponseTypeDef,
    CreateTemplateRequestRequestTypeDef,
    CreateTemplateResponseTypeDef,
    CreateThemeAliasRequestRequestTypeDef,
    CreateThemeAliasResponseTypeDef,
    CreateThemeRequestRequestTypeDef,
    CreateThemeResponseTypeDef,
    CredentialPairTypeDef,
    CustomSqlTypeDef,
    DashboardErrorTypeDef,
    DashboardPublishOptionsTypeDef,
    DashboardSearchFilterTypeDef,
    DashboardSourceEntityTypeDef,
    DashboardSourceTemplateTypeDef,
    DashboardSummaryTypeDef,
    DashboardTypeDef,
    DashboardVersionSummaryTypeDef,
    DashboardVersionTypeDef,
    DataColorPaletteTypeDef,
    DataSetConfigurationTypeDef,
    DataSetReferenceTypeDef,
    DataSetSchemaTypeDef,
    DataSetSummaryTypeDef,
    DataSetTypeDef,
    DataSetUsageConfigurationTypeDef,
    DataSourceCredentialsTypeDef,
    DataSourceErrorInfoTypeDef,
    DataSourceParametersTypeDef,
    DataSourceTypeDef,
    DateTimeParameterTypeDef,
    DecimalParameterTypeDef,
    DeleteAccountCustomizationRequestRequestTypeDef,
    DeleteAccountCustomizationResponseTypeDef,
    DeleteAnalysisRequestRequestTypeDef,
    DeleteAnalysisResponseTypeDef,
    DeleteDashboardRequestRequestTypeDef,
    DeleteDashboardResponseTypeDef,
    DeleteDataSetRequestRequestTypeDef,
    DeleteDataSetResponseTypeDef,
    DeleteDataSourceRequestRequestTypeDef,
    DeleteDataSourceResponseTypeDef,
    DeleteFolderMembershipRequestRequestTypeDef,
    DeleteFolderMembershipResponseTypeDef,
    DeleteFolderRequestRequestTypeDef,
    DeleteFolderResponseTypeDef,
    DeleteGroupMembershipRequestRequestTypeDef,
    DeleteGroupMembershipResponseTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteGroupResponseTypeDef,
    DeleteIAMPolicyAssignmentRequestRequestTypeDef,
    DeleteIAMPolicyAssignmentResponseTypeDef,
    DeleteNamespaceRequestRequestTypeDef,
    DeleteNamespaceResponseTypeDef,
    DeleteTemplateAliasRequestRequestTypeDef,
    DeleteTemplateAliasResponseTypeDef,
    DeleteTemplateRequestRequestTypeDef,
    DeleteTemplateResponseTypeDef,
    DeleteThemeAliasRequestRequestTypeDef,
    DeleteThemeAliasResponseTypeDef,
    DeleteThemeRequestRequestTypeDef,
    DeleteThemeResponseTypeDef,
    DeleteUserByPrincipalIdRequestRequestTypeDef,
    DeleteUserByPrincipalIdResponseTypeDef,
    DeleteUserRequestRequestTypeDef,
    DeleteUserResponseTypeDef,
    DescribeAccountCustomizationRequestRequestTypeDef,
    DescribeAccountCustomizationResponseTypeDef,
    DescribeAccountSettingsRequestRequestTypeDef,
    DescribeAccountSettingsResponseTypeDef,
    DescribeAnalysisPermissionsRequestRequestTypeDef,
    DescribeAnalysisPermissionsResponseTypeDef,
    DescribeAnalysisRequestRequestTypeDef,
    DescribeAnalysisResponseTypeDef,
    DescribeDashboardPermissionsRequestRequestTypeDef,
    DescribeDashboardPermissionsResponseTypeDef,
    DescribeDashboardRequestRequestTypeDef,
    DescribeDashboardResponseTypeDef,
    DescribeDataSetPermissionsRequestRequestTypeDef,
    DescribeDataSetPermissionsResponseTypeDef,
    DescribeDataSetRequestRequestTypeDef,
    DescribeDataSetResponseTypeDef,
    DescribeDataSourcePermissionsRequestRequestTypeDef,
    DescribeDataSourcePermissionsResponseTypeDef,
    DescribeDataSourceRequestRequestTypeDef,
    DescribeDataSourceResponseTypeDef,
    DescribeFolderPermissionsRequestRequestTypeDef,
    DescribeFolderPermissionsResponseTypeDef,
    DescribeFolderRequestRequestTypeDef,
    DescribeFolderResolvedPermissionsRequestRequestTypeDef,
    DescribeFolderResolvedPermissionsResponseTypeDef,
    DescribeFolderResponseTypeDef,
    DescribeGroupRequestRequestTypeDef,
    DescribeGroupResponseTypeDef,
    DescribeIAMPolicyAssignmentRequestRequestTypeDef,
    DescribeIAMPolicyAssignmentResponseTypeDef,
    DescribeIngestionRequestRequestTypeDef,
    DescribeIngestionResponseTypeDef,
    DescribeIpRestrictionRequestRequestTypeDef,
    DescribeIpRestrictionResponseTypeDef,
    DescribeNamespaceRequestRequestTypeDef,
    DescribeNamespaceResponseTypeDef,
    DescribeTemplateAliasRequestRequestTypeDef,
    DescribeTemplateAliasResponseTypeDef,
    DescribeTemplatePermissionsRequestRequestTypeDef,
    DescribeTemplatePermissionsResponseTypeDef,
    DescribeTemplateRequestRequestTypeDef,
    DescribeTemplateResponseTypeDef,
    DescribeThemeAliasRequestRequestTypeDef,
    DescribeThemeAliasResponseTypeDef,
    DescribeThemePermissionsRequestRequestTypeDef,
    DescribeThemePermissionsResponseTypeDef,
    DescribeThemeRequestRequestTypeDef,
    DescribeThemeResponseTypeDef,
    DescribeUserRequestRequestTypeDef,
    DescribeUserResponseTypeDef,
    ErrorInfoTypeDef,
    ExportToCSVOptionTypeDef,
    FieldFolderTypeDef,
    FilterOperationTypeDef,
    FolderMemberTypeDef,
    FolderSearchFilterTypeDef,
    FolderSummaryTypeDef,
    FolderTypeDef,
    GenerateEmbedUrlForAnonymousUserRequestRequestTypeDef,
    GenerateEmbedUrlForAnonymousUserResponseTypeDef,
    GenerateEmbedUrlForRegisteredUserRequestRequestTypeDef,
    GenerateEmbedUrlForRegisteredUserResponseTypeDef,
    GeoSpatialColumnGroupTypeDef,
    GetDashboardEmbedUrlRequestRequestTypeDef,
    GetDashboardEmbedUrlResponseTypeDef,
    GetSessionEmbedUrlRequestRequestTypeDef,
    GetSessionEmbedUrlResponseTypeDef,
    GroupMemberTypeDef,
    GroupTypeDef,
    GutterStyleTypeDef,
    IAMPolicyAssignmentSummaryTypeDef,
    IAMPolicyAssignmentTypeDef,
    IngestionTypeDef,
    InputColumnTypeDef,
    IntegerParameterTypeDef,
    JiraParametersTypeDef,
    JoinInstructionTypeDef,
    JoinKeyPropertiesTypeDef,
    ListAnalysesRequestRequestTypeDef,
    ListAnalysesResponseTypeDef,
    ListDashboardVersionsRequestRequestTypeDef,
    ListDashboardVersionsResponseTypeDef,
    ListDashboardsRequestRequestTypeDef,
    ListDashboardsResponseTypeDef,
    ListDataSetsRequestRequestTypeDef,
    ListDataSetsResponseTypeDef,
    ListDataSourcesRequestRequestTypeDef,
    ListDataSourcesResponseTypeDef,
    ListFolderMembersRequestRequestTypeDef,
    ListFolderMembersResponseTypeDef,
    ListFoldersRequestRequestTypeDef,
    ListFoldersResponseTypeDef,
    ListGroupMembershipsRequestRequestTypeDef,
    ListGroupMembershipsResponseTypeDef,
    ListGroupsRequestRequestTypeDef,
    ListGroupsResponseTypeDef,
    ListIAMPolicyAssignmentsForUserRequestRequestTypeDef,
    ListIAMPolicyAssignmentsForUserResponseTypeDef,
    ListIAMPolicyAssignmentsRequestRequestTypeDef,
    ListIAMPolicyAssignmentsResponseTypeDef,
    ListIngestionsRequestRequestTypeDef,
    ListIngestionsResponseTypeDef,
    ListNamespacesRequestRequestTypeDef,
    ListNamespacesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTemplateAliasesRequestRequestTypeDef,
    ListTemplateAliasesResponseTypeDef,
    ListTemplateVersionsRequestRequestTypeDef,
    ListTemplateVersionsResponseTypeDef,
    ListTemplatesRequestRequestTypeDef,
    ListTemplatesResponseTypeDef,
    ListThemeAliasesRequestRequestTypeDef,
    ListThemeAliasesResponseTypeDef,
    ListThemeVersionsRequestRequestTypeDef,
    ListThemeVersionsResponseTypeDef,
    ListThemesRequestRequestTypeDef,
    ListThemesResponseTypeDef,
    ListUserGroupsRequestRequestTypeDef,
    ListUserGroupsResponseTypeDef,
    ListUsersRequestRequestTypeDef,
    ListUsersResponseTypeDef,
    LogicalTableSourceTypeDef,
    LogicalTableTypeDef,
    ManifestFileLocationTypeDef,
    MarginStyleTypeDef,
    MariaDbParametersTypeDef,
    MemberIdArnPairTypeDef,
    MySqlParametersTypeDef,
    NamespaceErrorTypeDef,
    NamespaceInfoV2TypeDef,
    OracleParametersTypeDef,
    OutputColumnTypeDef,
    PaginatorConfigTypeDef,
    ParametersTypeDef,
    PhysicalTableTypeDef,
    PostgreSqlParametersTypeDef,
    PrestoParametersTypeDef,
    ProjectOperationTypeDef,
    QueueInfoTypeDef,
    RdsParametersTypeDef,
    RedshiftParametersTypeDef,
    RegisterUserRequestRequestTypeDef,
    RegisterUserResponseTypeDef,
    RegisteredUserDashboardEmbeddingConfigurationTypeDef,
    RegisteredUserEmbeddingExperienceConfigurationTypeDef,
    RegisteredUserQSearchBarEmbeddingConfigurationTypeDef,
    RegisteredUserQuickSightConsoleEmbeddingConfigurationTypeDef,
    RelationalTableTypeDef,
    RenameColumnOperationTypeDef,
    ResourcePermissionTypeDef,
    ResponseMetadataTypeDef,
    RestoreAnalysisRequestRequestTypeDef,
    RestoreAnalysisResponseTypeDef,
    RowInfoTypeDef,
    RowLevelPermissionDataSetTypeDef,
    RowLevelPermissionTagConfigurationTypeDef,
    RowLevelPermissionTagRuleTypeDef,
    S3ParametersTypeDef,
    S3SourceTypeDef,
    SearchAnalysesRequestRequestTypeDef,
    SearchAnalysesResponseTypeDef,
    SearchDashboardsRequestRequestTypeDef,
    SearchDashboardsResponseTypeDef,
    SearchFoldersRequestRequestTypeDef,
    SearchFoldersResponseTypeDef,
    ServiceNowParametersTypeDef,
    SessionTagTypeDef,
    SheetControlsOptionTypeDef,
    SheetStyleTypeDef,
    SheetTypeDef,
    SnowflakeParametersTypeDef,
    SparkParametersTypeDef,
    SqlServerParametersTypeDef,
    SslPropertiesTypeDef,
    StringParameterTypeDef,
    TagColumnOperationTypeDef,
    TagResourceRequestRequestTypeDef,
    TagResourceResponseTypeDef,
    TagTypeDef,
    TemplateAliasTypeDef,
    TemplateErrorTypeDef,
    TemplateSourceAnalysisTypeDef,
    TemplateSourceEntityTypeDef,
    TemplateSourceTemplateTypeDef,
    TemplateSummaryTypeDef,
    TemplateTypeDef,
    TemplateVersionSummaryTypeDef,
    TemplateVersionTypeDef,
    TeradataParametersTypeDef,
    ThemeAliasTypeDef,
    ThemeConfigurationTypeDef,
    ThemeErrorTypeDef,
    ThemeSummaryTypeDef,
    ThemeTypeDef,
    ThemeVersionSummaryTypeDef,
    ThemeVersionTypeDef,
    TileLayoutStyleTypeDef,
    TileStyleTypeDef,
    TransformOperationTypeDef,
    TwitterParametersTypeDef,
    UIColorPaletteTypeDef,
    UntagColumnOperationTypeDef,
    UntagResourceRequestRequestTypeDef,
    UntagResourceResponseTypeDef,
    UpdateAccountCustomizationRequestRequestTypeDef,
    UpdateAccountCustomizationResponseTypeDef,
    UpdateAccountSettingsRequestRequestTypeDef,
    UpdateAccountSettingsResponseTypeDef,
    UpdateAnalysisPermissionsRequestRequestTypeDef,
    UpdateAnalysisPermissionsResponseTypeDef,
    UpdateAnalysisRequestRequestTypeDef,
    UpdateAnalysisResponseTypeDef,
    UpdateDashboardPermissionsRequestRequestTypeDef,
    UpdateDashboardPermissionsResponseTypeDef,
    UpdateDashboardPublishedVersionRequestRequestTypeDef,
    UpdateDashboardPublishedVersionResponseTypeDef,
    UpdateDashboardRequestRequestTypeDef,
    UpdateDashboardResponseTypeDef,
    UpdateDataSetPermissionsRequestRequestTypeDef,
    UpdateDataSetPermissionsResponseTypeDef,
    UpdateDataSetRequestRequestTypeDef,
    UpdateDataSetResponseTypeDef,
    UpdateDataSourcePermissionsRequestRequestTypeDef,
    UpdateDataSourcePermissionsResponseTypeDef,
    UpdateDataSourceRequestRequestTypeDef,
    UpdateDataSourceResponseTypeDef,
    UpdateFolderPermissionsRequestRequestTypeDef,
    UpdateFolderPermissionsResponseTypeDef,
    UpdateFolderRequestRequestTypeDef,
    UpdateFolderResponseTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateGroupResponseTypeDef,
    UpdateIAMPolicyAssignmentRequestRequestTypeDef,
    UpdateIAMPolicyAssignmentResponseTypeDef,
    UpdateIpRestrictionRequestRequestTypeDef,
    UpdateIpRestrictionResponseTypeDef,
    UpdateTemplateAliasRequestRequestTypeDef,
    UpdateTemplateAliasResponseTypeDef,
    UpdateTemplatePermissionsRequestRequestTypeDef,
    UpdateTemplatePermissionsResponseTypeDef,
    UpdateTemplateRequestRequestTypeDef,
    UpdateTemplateResponseTypeDef,
    UpdateThemeAliasRequestRequestTypeDef,
    UpdateThemeAliasResponseTypeDef,
    UpdateThemePermissionsRequestRequestTypeDef,
    UpdateThemePermissionsResponseTypeDef,
    UpdateThemeRequestRequestTypeDef,
    UpdateThemeResponseTypeDef,
    UpdateUserRequestRequestTypeDef,
    UpdateUserResponseTypeDef,
    UploadSettingsTypeDef,
    UserTypeDef,
    VpcConnectionPropertiesTypeDef,
)

def get_structure() -> AccountCustomizationTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-quicksight` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-quicksight docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
